
import messytables
from messytables.types import *
import jsontableschema

__classes = {
    StringType: "string",
    IntegerType: "integer",
    FloatType: "number",
    DecimalType: "number",
    DateType: "date",
    DateUtilType: "date"
}

def celltype_as_string(celltype):
    return __classes[celltype.__class__]

def rowset_as_schema(rowset):
    _, headers = messytables.headers_guess(rowset.sample)
    types = map(celltype_as_string, messytables.type_guess(rowset.sample))

    j = jsontableschema.JSONTableSchema()

    for field_id, field_type in zip(headers, types):
        j.add_field(field_id=field_id, 
                    label=field_id,
                    field_type=field_type)

    return j



#!/usr/bin/env python
#coding: utf-8

from setuptools import setup

setup(
	name = "messytables-jts",
	author = "Martin Keegan",
	author_email = "martin.keegan@okfn.org",
	version = "0.3",
	license = "Apache Licence v2.0",
	url = "",
	download_url = "",
	description = "Python library for mapping Messytable cell types to strings",
	py_modules = ["messytables_jts"],
	install_requires = ["messytables", "json-table-schema"],
	scripts = ["bin/csv2jts"] 
)
